@@ -169,7 +169,7 @@ def lift_coordinates_liftover(data, object_id, chain_path, liftover_path):
     unMapped = open(unmapped_filename, "r")
     Lines = unMapped.readlines()
     if len(Lines) > 0:
-        print(f"{int(len(Lines)/2)} SNPs could not be lifted.")
+        print(f"{int(len(Lines)/2)} SNPs could not be lifted and are deleted from the final data.")
     else:
         print(f"All SNPs have been lifted.")
     indices = list()
@@ -230,9 +230,9 @@ def lift_coordinates_python(data, chain_path):
     data["POS"] = [res[0][1] if res else np.nan for res in results]
     data["CHR"] = [res[0][0].split("chr")[1] if res else np.nan for res in results]
     nrows = data.shape[0]
+    data["POS"] = pd.to_numeric(data["POS"], errors="coerce").astype("Int32")
+    data["CHR"] = pd.to_numeric(data["CHR"], errors="coerce").astype("Int32")
     data.dropna(subset=["POS", "CHR"], inplace=True)
-    data["POS"] = data["POS"].astype("Int32")
-    data["CHR"] = data["CHR"].astype("Int32")
     data.reset_index(drop=True, inplace=True)
     n_na = nrows - data.shape[0]
     if n_na:
